CHANGELOG
=========

0.2.0
----------

- [enhancement] switched CI to github actions
- [enhancement] blackify code
- [python] support only python 3.8 and up

0.1.0
----------

- initial release allowing to redirect all links section assigned to decoy to one url.
